@@ -1,10 +1,12 @@
 package Module::Install::ForC;
 use strict;
 use warnings;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 use 5.008000;
 use Module::Install::ForC::Env;
 use Config;
+use File::Basename ();
+use FindBin;
 
 use Module::Install::Base;
 our @ISA     = qw(Module::Install::Base);
@@ -25,15 +27,17 @@ sub is_mac   () { $^O eq 'darwin' }
 sub WriteMakefileForC {
     my $self = shift;
 
+    my $src = $self->_gen_makefile();
+
     open my $fh, '>', 'Makefile' or die "cannot open file: $!";
-    print $fh $self->_gen_makefile();
+    print $fh $src;
     close $fh;
 }
 
 sub _gen_makefile {
     my $self = shift;
-    die "missing name\n" unless $self->name;
-    die "missing version\n" unless $self->version;
+    $self->name(File::Basename::basename($FindBin::Bin)) unless $self->name;
+    $self->version('') unless defined $self->version;
 
     (my $make = <<"...") =~ s/^[ ]{4}/\t/gmsx;
 RM=$Config{rm}
